Other Resources
===============

Below are links to other repositories that use ``BigPlanet``:

`VPLanet Parameter Sweep <https://virtualplanetarylaboratory.github.io/vplanet/parametersweep.html>`_

`Ice Coverage (Wilhelm et al. 2022) repository <https://github.com/caitlyn-wilhelm/IceCoverage>`_ 

`Build the BigPlanet Archive, then build a file from it <https://github.com/caitlyn-wilhelm/IceCoverage/tree/main/StaticCases/>`_

`Build BigPlanet file from raw data <https://github.com/caitlyn-wilhelm/IceCoverage/tree/main/DynamicCases/>`_

`Extract archive data for a single simulation <https://github.com/caitlyn-wilhelm/IceCoverage/tree/main/ChaoticExample>`_

